# PyXiaomiGateway [![Build Status](https://travis-ci.org/Danielhiversen/PyXiaomiGateway.svg?branch=master)](https://travis-ci.org/Danielhiversen/PyXiaomiGateway)

A Python library to communicate with the Xiaomi Gateway
